EventAdd

Struct EventAdd 

pub struct EventAdd<'a> {
    pub event_name: Cow<'a, str>,
    pub location: Option<Cow<'a, str>>,
    pub event_days: Vec<DayOfWeek>,
    pub start_hr: TimeType,
    pub start_min: TimeType,
    pub end_hr: TimeType,
    pub end_min: TimeType,
}
A struct that represents an event to be added.

Prefer using the corresponding EventAddBuilder to build this object.

Fields

event_name: Cow<'a, str>

The name of the event. This is required.

location: Option<Cow<'a, str>>

The location of the event. This is optional.

event_days: Vec<DayOfWeek>

The days that this event will be held.

start_hr: TimeType

The hour start time. For example, if the event starts at 3:50 PM, use 15 (since 12 + 3 = 15).

start_min: TimeType

The minute start time. For example, if the event starts at 3:50 PM, use 50.

end_hr: TimeType

The hour end time. For example, if the event ends at 3:50 PM, use 15 (since 12 + 3 = 15).

end_min: TimeType

The minute end time. For example, if the event ends at 3:50 PM, use 50.

Implementations

Source

impl<'a> EventAdd<'a>

pub fn builder() -> EventAddBuilder<'a>

Creates a builder to construct this EventAdd object. This is recommended over directly creating the object yourself.

Returns

The builder.